<?php
namespace MyMenu\Controllers; 

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Session\Session;
use MyMenu\Libraries\KeyValueStorage;

class FaleConosco
{
    private $crudService;
    private $environment;
    private $sessionManager;
    private $smtp;

    public function __construct($crudService, $environment, Session $sessionManager, $smtp)
    {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->sessionManager = $sessionManager;
        $this->smtp = $smtp;
    }

    public function save(Request\Row $request, Response $response)
    {
        $dataSourceName = 'faleconoscoapp';
        $row = $request->getRow();

        $row["__is_new"] = true;
        $row["__new_code_pk"] = "FALECONOSCOAPP";
        $row["__table_pk"] = "NRFALECONOSCOAPP";
        $email = null;
        if($row["ISANON"]){
            $email = $row["DSEMAILUSUARIOAPP"] ? $row["DSEMAILUSUARIOAPP"] : 'anonimo@anonimo.com';
        }else{
            $email = KeyValueStorage::get("DSEMAILUSUARIOAPP") ? KeyValueStorage::get("DSEMAILUSUARIOAPP") : 'anonimo@anonimo.com';
        }
        
        $row["CDFILIAL"] = KeyValueStorage::get("CDFILIAL");
        $row["NRLOCALPESQ"] = KeyValueStorage::get("NRLOCALPESQ");
        $row["DSEMAILCLIENTE"] = $email;
        $row["DSEMAILRESPOSTA"] = "";
        $row["IDAPLICATIVO"] = "MYMENU";
        $row["IDSITUACAO"] = "PENDENTE";
        $row["DSRESPOSTAAPP"] = null;

        $dataSetToSave = new DataSet($dataSourceName, array($row));
        $saveRequest = new Request\DataSet($dataSetToSave, $request->getMethod(), $request->getRoutePath(), $request->getUserId());

        $rowsToSave = $this->crudService->getRowsToSave($saveRequest, $dataSourceName);
        $this->crudService->save($dataSourceName, $rowsToSave);

        $emailContato = $this->getEmailToNotify();
        $enviadoPor = $email;
        
        if($emailContato && $emailContato != null){
        
            $notificationData = array(
                "emailContato" => $emailContato,
                "enviadoPor" => $enviadoPor,
            );
            
            $body = $this->buildNotificationMail($row['DSFALECONOSCOAPP']);
            $this->smtp->sendNewFaleConoscoNotification($notificationData, $body);
        }
    }

    public function getEmailToNotify()
    {
        $conditions = array(
            array(
                "columnName" => "CDFILIAL",
                "operator" => "=",
                "value" => KeyValueStorage::get("CDFILIAL"),
            ),
            array(
                "columnName" => "NRORG",
                "operator" => "=",
                "value" => KeyValueStorage::get("NRORG"),
            ),
        );

        $rows = $this->crudService->getFilteredDataSet('check_email_filial', $conditions)->getRows();
        return count($rows) > 0 ? $rows[0]['DSEMAILFILI'] : null;
    }

    private function buildNotificationMail($message)
    {
        $title = "Fale Conosco Mymenu";
        $mailTemplate = file_get_contents(__DIR__ . "/../Templates/notification-mail.html");
        $content = mb_convert_encoding($mailTemplate, 'UTF-8', mb_detect_encoding($mailTemplate, 'UTF-8, ISO-8859-1', true));
        $footerMessage = "Email automático enviado pelo TecFood MyMenu.<br>Não responder.";
        $sendBy = KeyValueStorage::get("DSEMAILUSUARIOAPP");

        $search = array(
            "%title%",
            "%sendBy%",
            "%message%",
            "%footerMessage%",
        );
        $replace = array(
            $title,
            $sendBy,
            $message,
            $footerMessage,
        );
        
        return str_replace($search, $replace, $content);
        
    }
}
