<?php
namespace MyMenu\Util;

use Doctrine\DBAL\DriverManager;
use MyMenu\Services\JWT;
use MyMenu\Libraries\KeyValueStorage;
use MyMenu\Util\RequestHeader;

class ConnectionFactory extends \Zeedhi\Framework\ORM\ConnectionFactory {
    public static function updateConnectionParams(array $connectionParams, $config = null, $eventManager = null, $environment){
        
        // session_set_cookie_params(0, "/; samesite=none", "", true
        $token = self::getTokenFromHeaders();
        if(!empty($token) && !JWT::validateToken($token, "mymenuapp")){
            http_response_code(401);die;
        }
		$tokenData = empty($token) ? array() : JWT::getTokenData($token);
		KeyValueStorage::setAll($tokenData);
        self::buildSessionFromToken($tokenData, $environment);
        
        $nrOrg = false;

        if(isset($tokenData) && count($tokenData) > 0) {
            $nrOrg = isset($tokenData['NRORG']) ? $tokenData['NRORG'] : false;

            //Set current DBNAME in sessionData for use in login sessionData
            if(isset($connectionParams['sessionMode'])) {
                $tokenData['CURRENT_DBNAME'] = preg_replace('/[^A-Za-z0-9\-]/', '', self::encrypt($connectionParams['dbname'],'MPYIMREONCUA'));
            } else {
                $tokenData['CURRENT_DBNAME'] = preg_replace('/[^A-Za-z0-9\-]/', '', self::encrypt($connectionParams['user'], 'MPYIMREONCUA'));
            }
        }

        if ($nrOrg && isset($connectionParams['useVpd']) && $connectionParams['useVpd'] == 'true') {
            if (isset($connectionParams['vpdWithWallet']) && $connectionParams['vpdWithWallet'] == 'true') {
                unset($connectionParams['host']);
                unset($connectionParams['port']);
                $connectionParams['user'] = '/';
                $connectionParams['password'] = '';
                $connectionParams['dbname'] = 'USR_ORG_' . $nrOrg;
                $connectionParams['sessionMode'] = -2147483648;
            } else {
                $connectionParams['user'] = 'USR_ORG_' . $nrOrg;
                $connectionParams['password'] = $connectionParams['vpdPassword'];
                if (isset($connectionParams['isWallet']) && $connectionParams['isWallet'] == 'true') {
                    $connectionParams['dbname'] = isset($connectionParams['vpdDBNAME'])
                        ? $connectionParams['vpdDBNAME']
                        : $connectionParams['vpdDBName'];
                    $connectionParams['dbname'] = $connectionParams['vpdDBNAME'];
                    $connectionParams['host'] = $connectionParams['vpdHost'];
                    $connectionParams['port'] = $connectionParams['vpdPort'];
                    $connectionParams['service'] = $connectionParams['vpdService'];
                    unset($connectionParams['sessionMode']);
                }
            }
        }
        if(empty($connectionParams["password"])) {
            $connectionParams["password"] = '';
        } else if(isset($connectionParams["isEncrypted"]) && $connectionParams["isEncrypted"] == 'true') {
            $connectionParams["password"] = self::decrypt($connectionParams["password"], 'MPYIMREONCUA');
        }

        return DriverManager::getConnection($connectionParams, $config, $eventManager);
    }

    protected static function getTokenFromHeaders(){
        return RequestHeader::getKey("token");
    }

    protected static function buildSessionFromToken($tokenData, $environment){
        if($tokenData){
            $environment->setNrOrgTrab($tokenData["NRORG"]);
            $environment->setNrOrg($tokenData["NRORG"]);
            if(isset($tokenData["CDFILIAL"])){
                $environment->setCdFilial($tokenData["CDFILIAL"]);
            }
        }
    }
}