function MessageService(ScreenService, templateManager, $injector, $timeout) {
	
	var DEFAULT_PACKAGE = 'default';
	var ZEEDHI_PACKAGE = templateManager.ZEEDHI_PACKAGE;

	var messagePackages = {};
	var MetaDataLoader;

	$timeout(function initMessageService() {
		//call this asynchronously to avoid errors due to cyclic dependency
		MetaDataLoader = $injector.get('MetaDataLoader');
		messagePackages[DEFAULT_PACKAGE] = MetaDataLoader.loadMessagesFile(DEFAULT_PACKAGE);
		messagePackages[ZEEDHI_PACKAGE] = MetaDataLoader.loadMessagesFile(ZEEDHI_PACKAGE);
	});

	this.getMessageByCode = function(message) {
		var messageInfo = message.split('#');
		var messageCode = messageInfo.pop();
		var pckg = messageInfo.pop() || DEFAULT_PACKAGE;

		return getMessage(pckg, messageCode);
	};

	function getMessage(pckg, messageCode) {
		if(!messagePackages[pckg]) {
			messagePackages[pckg] = MetaDataLoader.loadMessagesFile(pckg);
		}

		return messagePackages[pckg].then(function(messages) {
			var message = messages[messageCode];
			if (!message) {
				throw new Error('Message "'+messageCode+'" not found on package "'+pckg+'"!');
			}

			return message;
		});
	}

	this.showMessageByCode = function(messageCode, messageParameters, messageConfig) {
		return this.getMessageByCode(messageCode).then(
			function showMessageByCode(message) {
				var type = messageConfig && messageConfig.type;
				var icon = messageConfig && messageConfig.icon;

				return ScreenService.showMessage(message, type, icon, messageParameters);
			}
		);
	};

	this.confirmMessageByCode = function(messageCode, messageParameters, messageConfig) {
		return this.getMessageByCode(messageCode).then(
			function confirmMessageByCode(message) {
				var type = messageConfig && messageConfig.type;
				var icon = messageConfig && messageConfig.icon;
				var success = messageConfig && messageConfig.success;
				var fail = messageConfig && messageConfig.fail;

				return ScreenService.confirmMessage(message, type, success, fail, icon, messageParameters);
			}
		);
	};

	this.showCustomDialogByCode = function(messageCode, messageParameters, dialogConfig) {
		return this.getMessageByCode(messageCode).then(
			function showCustomDialogByCode(message) {
				var type = dialogConfig && dialogConfig.type;
				var icon = dialogConfig && dialogConfig.icon;
				var actions = dialogConfig && dialogConfig.actions;

				return ScreenService.showCustomDialog(message, type, icon, actions, messageParameters);
			}
		);
	};

	this.notificationMessageByCode = function(messageCode, messageParameters, messageConfig) {
		return this.getMessageByCode(messageCode).then(
			function notificationMessageByCode(message) {
				var type = messageConfig && messageConfig.type;
				var time = messageConfig && messageConfig.time;

				ScreenService.notificationMessage(message, type, time, messageParameters);
			}
		);
	};

	this.alertNotificationByCode = function(messageCode, time, messageParameters) {
		return this.getMessageByCode(messageCode).then(
			function alertNotificationByCode(message) {
				ScreenService.alertNotification(message, time, messageParameters);
			}
		);
	};

	this.successNotificationByCode = function(messageCode, time, messageParameters) {
		return this.getMessageByCode(messageCode).then(
			function successNotificationByCode(message) {
				ScreenService.successNotification(message, time, messageParameters);
			}
		);
	};

	this.errorNotificationByCode = function(messageCode, messageParameters) {
		return this.getMessageByCode(messageCode).then(
			function errorNotificationByCode(message) {
				ScreenService.errorNotification(message, messageParameters);
			}
		);
	};
}