module.exports = function(grunt) {

	var assetsPath = ['src/registers/registerEvents.js', 'src/FilterBuilder.js', 'src/FilterWidgetsCreator.js', 'src/FilterFloatingCardController.js', 'src/FilterFloatingControlDirective.js', 'src/ZhFilterPreferences.js'];
	var specsPath = ['tests/specs/**/*.spec.js'];
	var helperPath = ['tests/helpers/**/*.js'];
	var dependenciesPath = [
		'node_modules/q/q.js',
		'bower_components/zeedhi-frontend/assets/dist/main.js',
		'bower_components/zh-customizations-service/dist/zhCustomizationsService.js',
		'node_modules/angular-mocks/angular-mocks.js',
	];

	grunt.initConfig({
		jshint: {
			all: ['GruntFile.js', assetsPath]
		},
		jasmine: {
			pivotal: {
				src: assetsPath,
				options: {
					vendor: dependenciesPath,
					specs: specsPath,
					helpers: helperPath,
					template: require('grunt-template-jasmine-istanbul'),
					templateOptions: {
						coverage: 'bin/coverage/coverage.json',
						report: 'bin/coverage',
						thresholds: {
							lines: 5,
							statements: 5,
							branches: 5,
							functions: 5
						}
					}
				}
			},
			toWatch: {
				src: assetsPath,
				options: {
					vendor: dependenciesPath,
					specs: specsPath,
					helpers: helperPath
				}
			}
		},
		watch: {
			pivotal: {
				files: [assetsPath],
				tasks: ['jshint']
			}
		},
		bump: {
			options: {
				files: ['bower.json', 'package.json'],
				pushTo: 'origin',
				commitFiles: ["-a"],
				push: true
			}
		},
		concat: {
			zh: {
				options: {
					process: function(src, filepath) {
						return '\n' + '// FILE: ' + filepath + '\n' + src;
					}
				},
				src: [assetsPath],
				dest: 'dist/zhFilterPreferences.js'
			}
		},
		uglify: {
			options: {
				mangle: false,
				compress: false,
				report: 'min',
				// the banner is inserted at the top of the output
				banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
			},
			dist: {
				files: {
					'dist/zhFilterPreferences.min.js': [assetsPath]
				}
			}
		},
		buildEnvironment: {
			development: {
				configFile: 'example/config/development.json'
			},
			deploy: {
				configFile: 'example/config/deploy.json'
			},
			srcFolders: ['example/frontend', 'example/frontend/tests']
		},
		zhIdGenerator: {
			options: {
				jsonPath: ['./example/frontend/json'],
				replaceIds: false
			}
		}
	});

	grunt.loadNpmTasks('grunt-bump');
	grunt.loadNpmTasks('grunt-contrib-concat');
	grunt.loadNpmTasks('grunt-contrib-jshint');
	grunt.loadNpmTasks('grunt-contrib-jasmine');
	grunt.loadNpmTasks('grunt-contrib-uglify');
	grunt.loadNpmTasks('grunt-contrib-watch');
	grunt.loadNpmTasks('grunt-zh-environment-builder');
	grunt.loadNpmTasks('grunt-zh-id-generator');

	// Default task.
	grunt.registerTask('default', ['jshint', 'jasmine:pivotal', 'concat', 'uglify']);
	grunt.registerTask('merge', ['jshint', 'jasmine:toWatch', 'concat']);
};